/*----------------------------------------------------------------------------
 * Name:    Blinky.c
 * Purpose: LED Flasher
 * Note(s):
 *----------------------------------------------------------------------------
 * This file is part of the uVision/ARM development tools.
 * This software may only be used under the terms of a valid, current,
 * end user licence from KEIL for a compatible version of KEIL software
 * development tools. Nothing else gives you the right to use this software.
 *
 * This software is supplied "AS IS" without warranties of any kind.
 *
 * Copyright (c) 2014 Keil - An ARM Company. All rights reserved.
 *----------------------------------------------------------------------------*/

#include "RTE_Components.h"             // Component selection
#include  CMSIS_device_header           // Device header
#include "Board_LED.h"                  // ::Board Support:LED
#include "Comparator_LPC812-LPCXpresso.h" // Keil.LPC812 LPCXpresso::Board Support:Comparator


volatile uint32_t msTicks = 0;                        /* counts 1ms timeTicks */
/*----------------------------------------------------------------------------
  SysTick_Handler
 *----------------------------------------------------------------------------*/
void SysTick_Handler(void) {
  msTicks++;                        /* increment counter necessary in Delay() */
}

/*----------------------------------------------------------------------------
  delays number of tick Systicks (happens every 1 ms)
 *----------------------------------------------------------------------------*/
void Delay (uint32_t dlyTicks) {
  uint32_t curTicks;

  curTicks = msTicks;
  while ((msTicks - curTicks) < dlyTicks) { __NOP(); }
}

/*----------------------------------------------------------------------------
  Main Program
 *----------------------------------------------------------------------------*/
int main (void) {
  uint32_t leds = 0x01;
  uint32_t ledNum = LED_GetCount();
  uint16_t dlyVal = 0;

  SystemCoreClockUpdate();

  LED_Initialize();                             /* LED Initialization         */
  Comparator_Initialize();                      /* CMP Initialization         */

  SysTick_Config(SystemCoreClock/1000);         /* Systick interrupt each 1ms */

  while(1) {                                    /* Loop forever               */

    dlyVal = Comparator_GetLad();               /* get Ladder value for delay */
    dlyVal = dlyVal << 5;                       /* scale delay value          */

    leds     <<= 1;
    if (leds >= (1 << ledNum)) leds = 0x01;
    LED_SetOut(leds);                           /* lit LEDs                   */
    Delay(dlyVal);                              /* Delay                      */
  }

}
