;/**************************************************************************//**
; * @file     startup_LPC8N04.s
; * @brief    CMSIS Core Device Startup File for
; *           NXP LPC8N04 Device Series
; * @version  V1.0.0
; * @date     05. December 2017
; *
; * @note
; * Copyright (C) 2017 ARM Limited. All rights reserved.
; *
; * @par
; * ARM Limited (ARM) is supplying this software for use with Cortex-M
; * processor based microcontrollers.  This file can be freely distributed
; * within development tools that are supporting such ARM based processors.
; *
; * @par
; * THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
; * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
; * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
; * ARM SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
; * CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
; *
; ******************************************************************************/

; *------- <<< Use Configuration Wizard in Context Menu >>> ------------------

; <h> Stack Configuration
;   <o> Stack Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Stack_Size      EQU     0x00000100

                AREA    STACK, NOINIT, READWRITE, ALIGN=3
Stack_Mem       SPACE   Stack_Size
__initial_sp


; <h> Heap Configuration
;   <o>  Heap Size (in Bytes) <0x0-0xFFFFFFFF:8>
; </h>

Heap_Size       EQU     0x00000000

                IF      Heap_Size != 0                ; Heap is provided
                AREA    HEAP, NOINIT, READWRITE, ALIGN=3
__heap_base
Heap_Mem        SPACE   Heap_Size
__heap_limit
                ELSE
                IMPORT __use_no_heap                  ; generate warning if heap is required
                ENDIF


                PRESERVE8
                THUMB


; Vector Table Mapped to Address 0 at Reset

                AREA    RESET, DATA, READONLY
                EXPORT  __Vectors

__Vectors       DCD     __initial_sp              ;       Top of Stack
                DCD     Reset_Handler             ;       Reset Handler
                DCD     NMI_Handler               ;       NMI Handler
                DCD     HardFault_Handler         ;       Hard Fault Handler
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     SVC_Handler               ;       SVCall Handler
                DCD     0                         ;       Reserved
                DCD     0                         ;       Reserved
                DCD     PendSV_Handler            ;       PendSV Handler
                DCD     SysTick_Handler           ;       SysTick Handler

                ; External Interrupts
                DCD     PIO0_0_IRQHandler         ; 16+ 0 PIO0_0 Start Logic Interrupt
                DCD     PIO0_1_IRQHandler         ; 16+ 1 PIO0_1 Start Logic Interrupt
                DCD     PIO0_2_IRQHandler         ; 16+ 2 PIO0_2 Start Logic Interrupt
                DCD     PIO0_3_IRQHandler         ; 16+ 3 PIO0_3 Start Logic Interrupt
                DCD     PIO0_4_IRQHandler         ; 16+ 4 PIO0_4 Start Logic Interrupt
                DCD     PIO0_5_IRQHandler         ; 16+ 5 PIO0_5 Start Logic Interrupt
                DCD     PIO0_6_IRQHandler         ; 16+ 6 PIO0_6 Start Logic Interrupt
                DCD     PIO0_7_IRQHandler         ; 16+ 7 PIO0_7 Start Logic Interrupt
                DCD     PIO0_8_IRQHandler         ; 16+ 8 PIO0_8 Start Logic Interrupt
                DCD     PIO0_9_IRQHandler         ; 16+ 9 PIO0_9 Start Logic Interrupt
                DCD     PIO0_10_IRQHandler        ; 16+10 PIO0_10 Start Logic Interrupt
                DCD     RFFIELD_IRQHandler        ; 16+11 NFC Access Start Logic Interrupt
                DCD     RTCPWREQ_IRQHandler       ; 16+12 RTC Wakeup Request Start Logic Interrupt
                DCD     NFC_IRQHandler            ; 16+13 NFC Read/Write Interrupt
                DCD     RTC_IRQHandler            ; 16+14 RTC Wakeup Interrupt
                DCD     I2C0_IRQHandler           ; 16+15 I2C0 Interrupt
                DCD     CT16B0_IRQHandler         ; 16+16 16-bit Timer 0 Interrupt
                DCD     PMUFLD_IRQHandler         ; 16+17 RF Power Detection Interrupt
                DCD     CT32B0_IRQHandler         ; 16+18 32-bit Timer 0 Interrupt
                DCD     PMUBOD_IRQHandler         ; 16+19 Brown Out Detection Interrupt
                DCD     SSP0_IRQHandler           ; 16+20 SSP0 Interrupt
                DCD     TSEN_IRQHandler           ; 16+21 Temperature Sensor Interrupt
                DCD     C2D_IRQHandler            ; 16+22 Capacitance-to-Digital converter Interrupt
                DCD     0                         ; 16+23 reserved
                DCD     I2D_IRQHandler            ; 16+24 Current-to-Digital converter Interrupt
                DCD     ADCDAC_IRQHandler         ; 16+25 Analog-to-Digital/Digital-to-Analog converter Interrupt
                DCD     WDT_IRQHandler            ; 16+26 Watchdog Timer Interrupt
                DCD     FLASH_IRQHandler          ; 16+27 FLASH memory Interrupt
                DCD     EEPROM_IRQHandler         ; 16+28 EEPROM memory Interrupt
                DCD     0                         ; 16+29 reserved
                DCD     0                         ; 16+30 reserved
                DCD     PIO0_IRQHandler           ; 16+31 GPIO Port 0 Interrupt
__Vectors_End
__Vectors_Size  EQU  __Vectors_End - __Vectors

                AREA    |.text|, CODE, READONLY

; Reset Handler

Reset_Handler   PROC
                EXPORT  Reset_Handler             [WEAK]
                IMPORT  SystemInit
                IMPORT  __main
                LDR     R0, =SystemInit
                BLX     R0
                LDR     R0, =__main
                BX      R0
                ENDP


; Dummy Exception Handlers (infinite loops which can be modified)
NMI_Handler     PROC
                EXPORT  NMI_Handler               [WEAK]
                B       .
                ENDP
HardFault_Handler\
                PROC
                EXPORT  HardFault_Handler         [WEAK]
                B       .
                ENDP
SVC_Handler     PROC
                EXPORT  SVC_Handler               [WEAK]
                B       .
                ENDP
PendSV_Handler  PROC
                EXPORT  PendSV_Handler            [WEAK]
                B       .
                ENDP
SysTick_Handler PROC
                EXPORT  SysTick_Handler           [WEAK]
                B       .
                ENDP

Default_Handler PROC

                EXPORT  PIO0_0_IRQHandler         [WEAK]
                EXPORT  PIO0_1_IRQHandler         [WEAK]
                EXPORT  PIO0_2_IRQHandler         [WEAK]
                EXPORT  PIO0_3_IRQHandler         [WEAK]
                EXPORT  PIO0_4_IRQHandler         [WEAK]
                EXPORT  PIO0_5_IRQHandler         [WEAK]
                EXPORT  PIO0_6_IRQHandler         [WEAK]
                EXPORT  PIO0_7_IRQHandler         [WEAK]
                EXPORT  PIO0_8_IRQHandler         [WEAK]
                EXPORT  PIO0_9_IRQHandler         [WEAK]
                EXPORT  PIO0_10_IRQHandler        [WEAK]
                EXPORT  RFFIELD_IRQHandler        [WEAK]
                EXPORT  RTCPWREQ_IRQHandler       [WEAK]
                EXPORT  NFC_IRQHandler            [WEAK]
                EXPORT  RTC_IRQHandler            [WEAK]
                EXPORT  I2C0_IRQHandler           [WEAK]
                EXPORT  CT16B0_IRQHandler         [WEAK]
                EXPORT  PMUFLD_IRQHandler         [WEAK]
                EXPORT  CT32B0_IRQHandler         [WEAK]
                EXPORT  PMUBOD_IRQHandler         [WEAK]
                EXPORT  SSP0_IRQHandler           [WEAK]
                EXPORT  TSEN_IRQHandler           [WEAK]
                EXPORT  C2D_IRQHandler            [WEAK]
                EXPORT  I2D_IRQHandler            [WEAK]
                EXPORT  ADCDAC_IRQHandler         [WEAK]
                EXPORT  WDT_IRQHandler            [WEAK]
                EXPORT  FLASH_IRQHandler          [WEAK]
                EXPORT  EEPROM_IRQHandler         [WEAK]
                EXPORT  PIO0_IRQHandler           [WEAK]

PIO0_0_IRQHandler
PIO0_1_IRQHandler
PIO0_2_IRQHandler
PIO0_3_IRQHandler
PIO0_4_IRQHandler
PIO0_5_IRQHandler
PIO0_6_IRQHandler
PIO0_7_IRQHandler
PIO0_8_IRQHandler
PIO0_9_IRQHandler
PIO0_10_IRQHandler
RFFIELD_IRQHandler
RTCPWREQ_IRQHandler
NFC_IRQHandler
RTC_IRQHandler
I2C0_IRQHandler
CT16B0_IRQHandler
PMUFLD_IRQHandler
CT32B0_IRQHandler
PMUBOD_IRQHandler
SSP0_IRQHandler
TSEN_IRQHandler
C2D_IRQHandler
I2D_IRQHandler
ADCDAC_IRQHandler
WDT_IRQHandler
FLASH_IRQHandler
EEPROM_IRQHandler
PIO0_IRQHandler

                B       .

                ENDP


                ALIGN


; User setup Stack & Heap

                IF      :LNOT::DEF:__MICROLIB
                IMPORT  __use_two_region_memory
                ENDIF

                EXPORT  __initial_sp
                IF      Heap_Size != 0                ; Heap is provided
                EXPORT  __heap_base
                EXPORT  __heap_limit
                ENDIF

                END
